==> jc-1.4.0.tar.gz: java/nio/BufferUnderflowException.h <==
// public class java.nio.BufferUnderflowException

// class file dependencies
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 4f5534a987354d1d java_lang_RuntimeException
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class 7734c6055a1233d0 java_nio_BufferUnderflowException

// header file dependencies
// @dep_header java_lang_RuntimeException

#include "java/lang/RuntimeException.h"

#ifndef _JC_java_nio_BufferUnderflowException_H_
#define _JC_java_nio_BufferUnderflowException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_nio_BufferUnderflowException$sub_refs	_jc_java_nio_BufferUnderflowException$sub_refs;
typedef struct _jc_java_nio_BufferUnderflowException$sub_nonrefs	_jc_java_nio_BufferUnderflowException$sub_nonrefs;
typedef struct _jc_java_nio_BufferUnderflowException$refs	_jc_java_nio_BufferUnderflowException$refs;
typedef struct _jc_java_nio_BufferUnderflowException$nonrefs	_jc_java_nio_BufferUnderflowException$nonrefs;
typedef struct _jc_java_nio_BufferUnderflowException$object	_jc_java_nio_BufferUnderflowException$object;

typedef const struct _jc_java_nio_BufferUnderflowException$vmethods	_jc_java_nio_BufferUnderflowException$vmethods;
typedef const struct _jc_java_nio_BufferUnderflowException$vtable	_jc_java_nio_BufferUnderflowException$vtable;
typedef const struct _jc_java_nio_BufferUnderflowException$vtype	_jc_java_nio_BufferUnderflowException$vtype;

// Constructors
extern void _jc_java_nio_BufferUnderflowException$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_nio_BufferUnderflowException$object *);

// Virtual methods structure
struct _jc_java_nio_BufferUnderflowException$vmethods {
};

// Vtable
struct _jc_java_nio_BufferUnderflowException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_lang_RuntimeException$vmethods	java_lang_RuntimeException;
	_jc_java_nio_BufferUnderflowException$vmethods	java_nio_BufferUnderflowException;
};

// Vtype
struct _jc_java_nio_BufferUnderflowException$vtype {
	_jc_type			type;
	_jc_java_nio_BufferUnderflowException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_nio_BufferUnderflowException$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_nio_BufferUnderflowException$refs {
    _jc_java_nio_BufferUnderflowException$sub_refs	java_nio_BufferUnderflowException;
    _jc_java_lang_RuntimeException$sub_refs	java_lang_RuntimeException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_nio_BufferUnderflowException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_nio_BufferUnderflowException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_lang_RuntimeException$sub_nonrefs	java_lang_RuntimeException;
    _jc_java_nio_BufferUnderflowException$sub_nonrefs	java_nio_BufferUnderflowException;
};

// Object instance structure
struct _jc_java_nio_BufferUnderflowException$object {
	_jc_java_nio_BufferUnderflowException$refs	refs[0];
	_jc_word		lockword;
	_jc_java_nio_BufferUnderflowException$vtype	*vtype;
	_jc_java_nio_BufferUnderflowException$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_nio_BufferUnderflowException$vtype _jc_java_nio_BufferUnderflowException$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_nio_BufferUnderflowException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_nio_BufferUnderflowException$class_object;

#endif	/* _JC_java_nio_BufferUnderflowException_H_ */

==> jc-1.4.6.tar.gz: java/nio/BufferUnderflowException.h <==
// public class java.nio.BufferUnderflowException

// class file dependencies
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 4f5534a987354d1d java_lang_RuntimeException
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class 7734c6055a1233d0 java_nio_BufferUnderflowException

// header file dependencies
// @dep_header java_lang_RuntimeException

#include "java/lang/RuntimeException.h"

#ifndef _JC_java_nio_BufferUnderflowException_H_
#define _JC_java_nio_BufferUnderflowException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_nio_BufferUnderflowException$sub_refs	_jc_java_nio_BufferUnderflowException$sub_refs;
typedef struct _jc_java_nio_BufferUnderflowException$sub_nonrefs	_jc_java_nio_BufferUnderflowException$sub_nonrefs;
typedef struct _jc_java_nio_BufferUnderflowException$refs	_jc_java_nio_BufferUnderflowException$refs;
typedef struct _jc_java_nio_BufferUnderflowException$nonrefs	_jc_java_nio_BufferUnderflowException$nonrefs;
typedef struct _jc_java_nio_BufferUnderflowException$object	_jc_java_nio_BufferUnderflowException$object;

typedef const struct _jc_java_nio_BufferUnderflowException$vmethods	_jc_java_nio_BufferUnderflowException$vmethods;
typedef const struct _jc_java_nio_BufferUnderflowException$vtable	_jc_java_nio_BufferUnderflowException$vtable;
typedef const struct _jc_java_nio_BufferUnderflowException$vtype	_jc_java_nio_BufferUnderflowException$vtype;

// Constructors
extern void _jc_java_nio_BufferUnderflowException$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_nio_BufferUnderflowException$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_java_nio_BufferUnderflowException$vmethods {
};

// Vtable
struct _jc_java_nio_BufferUnderflowException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_lang_RuntimeException$vmethods	java_lang_RuntimeException;
	_jc_java_nio_BufferUnderflowException$vmethods	java_nio_BufferUnderflowException;
};

// Vtype
struct _jc_java_nio_BufferUnderflowException$vtype {
	_jc_type			type;
	_jc_java_nio_BufferUnderflowException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_nio_BufferUnderflowException$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_nio_BufferUnderflowException$refs {
    _jc_java_nio_BufferUnderflowException$sub_refs	java_nio_BufferUnderflowException;
    _jc_java_lang_RuntimeException$sub_refs	java_lang_RuntimeException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_nio_BufferUnderflowException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_nio_BufferUnderflowException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_lang_RuntimeException$sub_nonrefs	java_lang_RuntimeException;
    _jc_java_nio_BufferUnderflowException$sub_nonrefs	java_nio_BufferUnderflowException;
};

// Object instance structure
struct _jc_java_nio_BufferUnderflowException$object {
	_jc_java_nio_BufferUnderflowException$refs	refs[0];
	_jc_word		lockword;
	_jc_java_nio_BufferUnderflowException$vtype	*vtype;
	_jc_java_nio_BufferUnderflowException$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_nio_BufferUnderflowException$vtype _jc_java_nio_BufferUnderflowException$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_nio_BufferUnderflowException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_nio_BufferUnderflowException$class_object;

#endif	/* _JC_java_nio_BufferUnderflowException_H_ */
